@@ -367,7 +367,7 @@ class PSquared(object):
         if None != options and 0 != len(options):
             conjunction = '?'
             for key, value in options.items():
-                query = query + conjunction + key + '=' + value
+                query = query + conjunction + value[0] + '=' + value[1]
         return query
 
 
@@ -401,7 +401,7 @@ class PSquared(object):
         :raises FatalError: if the server response is not OK.
         """
 
-        configuration, application = self.get_configuration(config)
+        configuration, application = self.get_configuration(config, options = ('details', 'full'))
         url = application.find('uri').text
         if None == vers:
             v = configuration.find('default-version')
@@ -439,7 +439,7 @@ class PSquared(object):
                                                                                                                                                                        :raises FatalError: if the server response in not OK.
         """
 
-        version, configuration, application = self.get_version(config, vers)
+        version, configuration, application = self.get_version(config, vers, options = ('details', 'full'))
         version_in_use = version.find('name').text
         cmd = version.find(xpath + '/[name="' + name + '"]')
         if None == cmd:
